@@ -1,5 +1,5 @@
 package Search::Elasticsearch::Client::Direct::Cat;
-$Search::Elasticsearch::Client::Direct::Cat::VERSION = '1.17';
+$Search::Elasticsearch::Client::Direct::Cat::VERSION = '1.19';
 use Moo;
 with 'Search::Elasticsearch::Role::API';
 with 'Search::Elasticsearch::Role::Client::Direct';
@@ -28,7 +28,7 @@ Search::Elasticsearch::Client::Direct::Cat - A client for running cat debugging
 
 =head1 VERSION
 
-version 1.17
+version 1.19
 
 =head1 DESCRIPTION
 
@@ -278,6 +278,22 @@ Query string parameters:
 See the L<cat recovery docs|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/cat-recovery.html>
 for more information.
 
+=head2 C<segments()>
+
+    say $e->cat->segments(
+        index => 'index' | \@indices    # optional
+    );
+
+Provides low level information about the segments in the shards of an index.
+
+Query string parameters:
+    C<h>,
+    C<help>,
+    C<v>
+
+See the L<cat shards docs|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/cat-segments.html>
+for more information.
+
 =head2 C<shards()>
 
     say $e->cat->shards(
@@ -324,7 +340,7 @@ Clinton Gormley <drtech@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by Elasticsearch BV.
+This software is Copyright (c) 2015 by Elasticsearch BV.
 
 This is free software, licensed under:
 
