@@ -1,5 +1,5 @@
 package Search::Elasticsearch::Cxn::HTTPTiny;
-$Search::Elasticsearch::Cxn::HTTPTiny::VERSION = '1.17';
+$Search::Elasticsearch::Cxn::HTTPTiny::VERSION = '1.19';
 use Moo;
 with 'Search::Elasticsearch::Role::Cxn::HTTP',
     'Search::Elasticsearch::Role::Cxn',
@@ -49,6 +49,7 @@ sub error_from_text {
     return
           /[Tt]imed out/             ? 'Timeout'
         : /Unexpected end of stream/ ? 'ContentLength'
+        : /SSL connection failed/    ? 'SSL'
         : /$Cxn_Error/               ? 'Cxn'
         :                              'Request';
 }
@@ -60,6 +61,9 @@ sub _build_handle {
     my %args = ( default_headers => $self->default_headers );
     if ( $self->is_https && $self->has_ssl_options ) {
         $args{SSL_options} = $self->ssl_options;
+        if ( $args{SSL_options}{SSL_verify_mode} ) {
+            $args{verify_ssl} = 1;
+        }
     }
 
     return HTTP::Tiny->new( %args, %{ $self->handle_args } );
@@ -81,7 +85,7 @@ Search::Elasticsearch::Cxn::HTTPTiny - A Cxn implementation which uses HTTP::Tin
 
 =head1 VERSION
 
-version 1.17
+version 1.19
 
 =head1 DESCRIPTION
 
@@ -149,11 +153,13 @@ attacks, you could do the following:
         ],
         ssl_options => {
             SSL_verify_mode     => SSL_VERIFY_PEER,
-            SSL_ca_file         => '/path/to/cacert.pem',
-            SSL_verifycn_scheme => 'http',
+            SSL_ca_file         => '/path/to/cacert.pem'
         }
     );
 
+If the remote server cannot be verified, an
+L<Search::Elasticsearch::Error|SSL error> will be thrown.
+
 If you want your client to present its own certificate to the remote
 server, then use:
 
@@ -167,8 +173,8 @@ server, then use:
         ],
         ssl_options => {
             SSL_verify_mode     => SSL_VERIFY_PEER,
+            SSL_use_cert        => 1,
             SSL_ca_file         => '/path/to/cacert.pem',
-            SSL_verifycn_scheme => 'http',
             SSL_cert_file       => '/path/to/client.pem',
             SSL_key_file        => '/path/to/client.pem',
         }
@@ -266,7 +272,7 @@ Clinton Gormley <drtech@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by Elasticsearch BV.
+This software is Copyright (c) 2015 by Elasticsearch BV.
 
 This is free software, licensed under:
 
