@@ -1,5 +1,5 @@
 package Search::Elasticsearch::Cxn::LWP;
-$Search::Elasticsearch::Cxn::LWP::VERSION = '1.17';
+$Search::Elasticsearch::Cxn::LWP::VERSION = '1.19';
 use Moo;
 with 'Search::Elasticsearch::Role::Cxn::HTTP',
     'Search::Elasticsearch::Role::Cxn',
@@ -94,7 +94,7 @@ Search::Elasticsearch::Cxn::LWP - A Cxn implementation which uses LWP
 
 =head1 VERSION
 
-version 1.17
+version 1.19
 
 =head1 DESCRIPTION
 
@@ -152,7 +152,6 @@ that the remote host has a trusted certificate, and to avoid man-in-the-middle
 attacks, you could do the following:
 
     use Search::Elasticsearch;
-    use IO::Socket::SSL;
 
     my $es = Search::Elasticsearch->new(
         cxn   => 'LWP',
@@ -161,17 +160,19 @@ attacks, you could do the following:
             "https://node2.mydomain.com:9200",
         ],
         ssl_options => {
-            SSL_verify_mode     => SSL_VERIFY_PEER,
-            SSL_ca_file         => '/path/to/cacert.pem',
-            SSL_verifycn_scheme => 'http',
+            verify_hostname     => 1,
+            SSL_ca_file         => '/path/to/cacert.pem'
         }
     );
 
+If the remote server cannot be verified, an
+L<Search::Elasticsearch::Error|Cxn error> will be thrown - LWP does not
+allow us to detect that the connection error was due to invalid SSL.
+
 If you want your client to present its own certificate to the remote
 server, then use:
 
     use Search::Elasticsearch;
-    use IO::Socket::SSL;
 
     my $es = Search::Elasticsearch->new(
         cxn   => 'LWP',
@@ -180,9 +181,9 @@ server, then use:
             "https://node2.mydomain.com:9200",
         ],
         ssl_options => {
-            SSL_verify_mode     => SSL_VERIFY_PEER,
+            verify_hostname     => 1,
             SSL_ca_file         => '/path/to/cacert.pem',
-            SSL_verifycn_scheme => 'http',
+            SSL_use_cert        => 1,
             SSL_cert_file       => '/path/to/client.pem',
             SSL_key_file        => '/path/to/client.pem',
         }
@@ -280,7 +281,7 @@ Clinton Gormley <drtech@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by Elasticsearch BV.
+This software is Copyright (c) 2015 by Elasticsearch BV.
 
 This is free software, licensed under:
 
