@@ -1,17 +1,18 @@
 package Search::Elasticsearch::Error;
-$Search::Elasticsearch::Error::VERSION = '1.17';
+$Search::Elasticsearch::Error::VERSION = '1.19';
 use Moo;
 
 our $DEBUG = 0;
 
-@Search::Elasticsearch::Error::Internal::ISA       = __PACKAGE__;
-@Search::Elasticsearch::Error::Param::ISA          = __PACKAGE__;
-@Search::Elasticsearch::Error::NoNodes::ISA        = __PACKAGE__;
-@Search::Elasticsearch::Error::ClusterBlocked::ISA = __PACKAGE__;
-@Search::Elasticsearch::Error::Request::ISA        = __PACKAGE__;
-@Search::Elasticsearch::Error::Timeout::ISA        = __PACKAGE__;
-@Search::Elasticsearch::Error::Cxn::ISA            = __PACKAGE__;
-@Search::Elasticsearch::Error::Serializer::ISA     = __PACKAGE__;
+@Search::Elasticsearch::Error::Internal::ISA     = __PACKAGE__;
+@Search::Elasticsearch::Error::Param::ISA        = __PACKAGE__;
+@Search::Elasticsearch::Error::NoNodes::ISA      = __PACKAGE__;
+@Search::Elasticsearch::Error::Unauthorized::ISA = __PACKAGE__;
+@Search::Elasticsearch::Error::Forbidden::ISA    = __PACKAGE__;
+@Search::Elasticsearch::Error::Request::ISA      = __PACKAGE__;
+@Search::Elasticsearch::Error::Timeout::ISA      = __PACKAGE__;
+@Search::Elasticsearch::Error::Cxn::ISA          = __PACKAGE__;
+@Search::Elasticsearch::Error::Serializer::ISA   = __PACKAGE__;
 
 @Search::Elasticsearch::Error::Conflict::ISA
     = ( 'Search::Elasticsearch::Error::Request', __PACKAGE__ );
@@ -22,6 +23,9 @@ our $DEBUG = 0;
 @Search::Elasticsearch::Error::ContentLength::ISA
     = ( __PACKAGE__, 'Search::Elasticsearch::Error::Request' );
 
+@Search::Elasticsearch::Error::SSL::ISA
+    = ( __PACKAGE__, 'Search::Elasticsearch::Error::Cxn' );
+
 @Search::Elasticsearch::Error::Unavailable::ISA
     = ( 'Search::Elasticsearch::Error::Cxn', __PACKAGE__ );
 
@@ -158,7 +162,7 @@ Search::Elasticsearch::Error - Errors thrown by Search::Elasticsearch
 
 =head1 VERSION
 
-version 1.17
+version 1.19
 
 =head1 DESCRIPTION
 
@@ -194,6 +198,11 @@ has the following sub-classes:
 
 =over
 
+=item * C<Search::Elasticsearch::Error::Unauthorized>
+
+Invalid (or no) username/password provided as C<userinfo> for a password
+protected service. These errors are triggered by the C<401> HTTP status code.
+
 =item * C<Search::Elasticsearch::Error::Missing>
 
 A resource that you requested was not found.  These errors are triggered
@@ -222,7 +231,7 @@ The request timed out.
 
 There was an error connecting to a node in the cluster.  This error
 indicates node failure and will be retried on another node.
-This error has the following sub-class:
+This error has the following sub-classes:
 
 =over
 
@@ -232,13 +241,19 @@ The current node is unable to handle your request at the moment. Your
 request will be retried on another node.  This error is triggered by
 the C<503> HTTP status code.
 
+=item * C<Search::Elasticsearch::Error::SSL>
+
+There was a problem validating the SSL certificate.  Not all
+backends support this error type.
+
 =back
 
-=item * C<Search::Elasticsearch::Error::ClusterBlocked>
+=item * C<Search::Elasticsearch::Error::Forbidden>
 
-The cluster was unable to process the request because it is currently blocking,
-eg there are not enough master nodes to form a cluster. This error is
-triggered by the C<403> HTTP status code.
+Either the cluster was unable to process the request because it is currently
+blocking, eg there are not enough master nodes to form a cluster, or
+because the authenticated user is trying to perform an unauthorized
+action. This error is triggered by the C<403> HTTP status code.
 
 =item * C<Search::Elasticsearch::Error::Serializer>
 
@@ -257,7 +272,7 @@ Clinton Gormley <drtech@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by Elasticsearch BV.
+This software is Copyright (c) 2015 by Elasticsearch BV.
 
 This is free software, licensed under:
 
