@@ -1,5 +1,5 @@
 package Search::Elasticsearch::Role::API;
-$Search::Elasticsearch::Role::API::VERSION = '1.17';
+$Search::Elasticsearch::Role::API::VERSION = '1.19';
 use Moo::Role;
 
 use Search::Elasticsearch::Util qw(throw);
@@ -754,6 +754,16 @@ sub api {
         qs => [ "bytes", "h", "help", "master_timeout", "v" ],
     },
 
+    'cat.segments' => {
+        doc   => "cat-segments",
+        parts => { index => { multi => 1 } },
+        paths => [
+            [ { index => 2 }, "_cat", "segments", "{index}" ],
+            [ {}, "_cat", "segments" ],
+        ],
+        qs => [ "h", "help", "v" ],
+    },
+
     'cat.shards' => {
         doc   => "cat-shards",
         parts => { index => { multi => 1 } },
@@ -1602,7 +1612,7 @@ Search::Elasticsearch::Role::API - This class contains the spec for the Elastics
 
 =head1 VERSION
 
-version 1.17
+version 1.19
 
 =head1 DESCRIPTION
 
@@ -1665,7 +1675,7 @@ Clinton Gormley <drtech@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by Elasticsearch BV.
+This software is Copyright (c) 2015 by Elasticsearch BV.
 
 This is free software, licensed under:
 
