@@ -1,5 +1,5 @@
 package Search::Elasticsearch::Role::Cxn;
-$Search::Elasticsearch::Role::Cxn::VERSION = '1.17';
+$Search::Elasticsearch::Role::Cxn::VERSION = '1.19';
 use Moo::Role;
 use Search::Elasticsearch::Util qw(throw);
 use List::Util qw(min);
@@ -27,7 +27,8 @@ has 'handle_args'           => ( is => 'ro', default  => sub { {} } );
 
 my %Code_To_Error = (
     400 => 'Request',
-    403 => 'ClusterBlocked',
+    401 => 'Unauthorized',
+    403 => 'Forbidden',
     404 => 'Missing',
     409 => 'Conflict',
     503 => 'Unavailable'
@@ -183,7 +184,7 @@ Search::Elasticsearch::Role::Cxn - Provides common functionality to Cxn implemen
 
 =head1 VERSION
 
-version 1.17
+version 1.19
 
 =head1 DESCRIPTION
 
@@ -401,7 +402,7 @@ Clinton Gormley <drtech@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by Elasticsearch BV.
+This software is Copyright (c) 2015 by Elasticsearch BV.
 
 This is free software, licensed under:
 
